@@ -1,13 +1,28 @@
 #' Polarity Score (Sentiment Analysis)
 #'
-#' Approximate the sentiment (polarity) of text by sentence.
+#' Approximate the sentiment (polarity) of text by sentence.  This function allows
+#' the user to easily alter (add, change, replace) the default polarity an 
+#' valence shifters dictionaries to suit the context dependent needs of a particular
+#' data set.  See the \code{polarity_dt} and \code{valence_shifters_dt} arguments
+#' for more information.  Other hyper-parameters may add additional fine tuned 
+#' control of the algorithm that may boost performance in different contexts.
 #'
 #' @param text.var The text variable.
 #' @param polarity_dt A \pkg{data.table} of positive/negative words and
-#' weights with x and y as column names.
+#' weights with x and y as column names.  The \pkg{lexicon} package has 4 
+#' dictionaries that can be used here: \code{lexicon::hash_sentiment_huliu}, 
+#' \code{lexicon::hash_sentiment_jockers}, \code{lexicon::hash_sentiment_nrc}, 
+#' and \code{lexicon::hash_sentiment_sentiword}.  Additionally, the 
+#' \code{as_key} function can be used to make a sentiment frame suitable for
+#' \code{polarity_dt}.  This takes a 2 column data.frame with the first column
+#' being words and the second column being polarity values.  Note that as of 
+#' version 1.0.0 \pkg{sentimentr} switched from the Liu & HU (2004) dictionary
+#' as the default to Jocker's (2017) dictionary from the \pkg{syuzhet} package.
+#' Use \code{lexicon::hash_sentiment_huliu} to obtain the old behavior.
 #' @param valence_shifters_dt A \pkg{data.table} of valence shifters that
 #' can alter a polarized word's meaning and an integer key for negators (1),
-#' amplifiers(2), and de-amplifiers (3) with x and y as column names.
+#' amplifiers(2), de-amplifiers (3) and (4) adversative conjunctions with x and 
+#' y as column names.
 #' @param hyphen The character string to replace hyphens with.  Default replaces
 #' with nothing so 'sugar-free' becomes 'sugarfree'.  Setting \code{hyphen = " "}
 #' would result in a space between words (e.g., 'sugar free').
@@ -24,20 +39,22 @@
 #' Default is 1.  A 0 corresponds with the belief that questions (pure questions)
 #' are not polarized.  A weight may be applied based on the evidence that the
 #' questions function with polarized sentiment.
-#' @param but.weight The weight to give to "but" style conjunctions that overrule
-#' the previous clause.  Weighting a but statement stems from the belief that
-#' the conjunctions "but", "however", and "although" amplify the current clause
-#' and/or down weight the prior clause.  If a but conjunction is located before
-#' polarized word in the context cluster the cluster is up-weighted 1 + number
-#' of occurrences of the but conjunctions before the polarized word times the
-#' weight given (\eqn{1 + N_{but\,conjunctions} * z_2} where \eqn{z_2} is the
-#' \code{but.weight}).  Conversely,
-#' a but conjunction found after the polarized word in a context cluster
-#' down weights the cluster 1 - number of occurrences of the but conjunctions
-#' after the polarized word times the weight given
-#' (\eqn{1 + N_{but\,conjunctions}*-1 * z_2}).  These are added to the
-#' deamplifier and amplifier weights and thus the down weight is constrained to
-#' -1 as the lower bound.  Set to zero to remove but conjunction weighting.
+#' @param adversative.weight The weight to give to adversative conjunctions or 
+#' contrasting conjunctions (e.g., "but") that overrule the previous clause 
+#' (Halliday & Hasan, 2013).  Weighting a contrasting statement stems from the 
+#' belief that the adversative conjunctions like "but", "however", and "although" 
+#' amplify the current clause and/or down weight the prior clause.  If an 
+#' adversative conjunction is located before the polarized word in the context 
+#' cluster the cluster is up-weighted 1 + number of occurrences of the 
+#' adversative conjunctions before the polarized word times the
+#' weight given (\eqn{1 + N_{adversative\,conjunctions} * z_2} where \eqn{z_2} 
+#' is the \code{adversative.weight}).  Conversely, an adversative conjunction 
+#' found after the polarized word in a context cluster down weights the cluster 
+#' 1 - number of occurrences of the adversative conjunctions after the polarized 
+#' word times the weight given (\eqn{1 + N_{adversative\,conjunctions}*-1 * z_2}).  
+#' These are added to the deamplifier and amplifier weights and thus the down 
+#' weight is constrained to -1 as the lower bound.  Set to zero to remove 
+#' adversative conjunction weighting.
 #' @param missing_value A value to replace \code{NA}/\code{NaN} with.  Use
 #' \code{NULL} to retain missing values.
 #' @param \ldots Ignored.
@@ -48,9 +65,14 @@
 #'   \item  word_count - Word count
 #'   \item  sentiment - Sentiment/polarity score
 #' }
-#' @references Hu, M., & Liu, B. (2004). Mining opinion features in customer
+#' @references Jockers, M. L. (2017). Syuzhet: Extract sentiment and plot arcs 
+#' from text. Retrieved from https://github.com/mjockers/syuzhet
+#' 
+#' Hu, M., & Liu, B. (2004). Mining opinion features in customer
 #' reviews. National Conference on Artificial Intelligence.
-#'
+#' 
+#' Halliday, M. A. K. & Hasan, R. (2013). Cohesion in English. New York, NY: Routledge.
+#' 
 #' \url{http://www.slideshare.net/jeffreybreen/r-by-example-mining-twitter-for}
 #'
 #' \url{http://hedonometer.org/papers.html} Links to papers on hedonometrics
@@ -59,16 +81,16 @@
 #' @family sentiment functions
 #' @seealso \url{https://github.com/trestletech/Sermon-Sentiment-Analysis}
 #' @note The polarity score is dependent upon the polarity dictionary used.
-#' This function defaults to the word polarity dictionary used by Hu, M., &
-#' Liu, B. (2004), however, this may not be appropriate for the context of
-#' children in a classroom.  The user may (is encouraged) to provide/augment the
-#' dictionary (see the \code{as_key} function).  For instance the word
-#' "sick" in a high school setting may mean that something is good, whereas
-#' "sick" used by a typical adult indicates something is not right or negative
-#' connotation (\strong{deixis}).
+#' This function defaults to a slightly modified vaersion of the polarity word  
+#' dictionary used by Jockers (2017), however, this may not be appropriate, for 
+#' example, in the context of children in a classroom.  The user may (is 
+#' encouraged) to provide/augment the dictionary (see the \code{as_key} 
+#' function).  For instance the word "sick" in a high school setting may mean 
+#' that something is good, whereas "sick" used by a typical adult indicates 
+#' something is not right or negative connotation (\strong{deixis}).
 #' @details The equation used by the algorithm to assign value to polarity of
-#' each sentence fist utilizes the sentiment dictionary (Hu and Liu, 2004) to
-#' tag polarized words.  Each paragraph
+#' each sentence fist utilizes the sentiment dictionary (e.g., Jockers, 2017) 
+#' to tag polarized words.  Each paragraph
 #' (\eqn{p_i = \{s_1, s_2, ..., s_n\}}{p_i = \{s_1, s_2, ... s_n\}}) composed of
 #' sentences, is broken into element sentences
 #' (\eqn{s_i,j = \{w_1, w_2, ..., w_n\}}{s_i,j = \{w_1, w_2, ... w_n\}}) where \eqn{w}
@@ -83,12 +105,13 @@
 #' response in a questionnaire composed of sentences.
 #'
 #' The words in each sentence (\eqn{w_{i,j,k}}) are searched and compared to a
-#' modified version of Hu, M., & Liu, B.'s (2004) dictionary of polarized words.
-#' Positive (\eqn{w_{i,j,k}^{+}}{w_i,j,k^+}) and negative
-#' (\eqn{w_{i,j,k}^{-}}{w_i,j,k^-}) words are tagged with a \eqn{+1} and \eqn{-1}
-#' respectively.  I will denote polarized words as \eqn{pw} for convenience. These
-#' will form a polar cluster (\eqn{c_{i,j,l}}{c_i,j,l}) which is a subset of the a
-#' sentence (\eqn{c_{i,j,l} \subseteq s_i,j }{l_i,j,l \subseteq s_i,j}).
+#' dictionary of polarized words (e.g., Jockers (2017) dictionary found in 
+#' the \pkg{lexicon} package).  Positive (\eqn{w_{i,j,k}^{+}}{w_i,j,k^+}) and
+#'  negative (\eqn{w_{i,j,k}^{-}}{w_i,j,k^-}) words are tagged with a \eqn{+1} 
+#'  and \eqn{-1} respectively.  I will denote polarized words as \eqn{pw} for 
+#'  convenience. These will form a polar cluster (\eqn{c_{i,j,l}}{c_i,j,l}) 
+#'  which is a subset of the a sentence 
+#'  (\eqn{c_{i,j,l} \subseteq s_i,j }{l_i,j,l \subseteq s_i,j}).
 #'
 #' The polarized context cluster (\eqn{c_{i,j,l}}) of words is pulled from around
 #' the polarized word (\eqn{pw}) and defaults to 4 words before and two words
@@ -122,18 +145,19 @@
 #' negators (\eqn{w_{i,j,k}^{n}}) + 2.  Simply, this is a result of a belief that two
 #' negatives equal a positive, 3 negatives a negative and so on.
 #'
-#' The "but" conjunctions (i.e., 'but', 'however', and 'although') also weight
-#' the context cluster.  A but conjunction before the polarized word
-#' (\eqn{w_{but\,conjunction}, ..., w_{i, j, k}^{p}}) up-weights the cluster by
-#' \eqn{1 + z_2 * \{|w_{but\,conjunction}|, ..., w_{i, j, k}^{p}\}} (.85 is the
-#' default weight (\eqn{z_2})).  A but conjunction after the polarized word
-#' down-weights the cluster by
-#' \eqn{1 + \{w_{i, j, k}^{p}, ..., |w_{but\,conjunction}| * -1\} * z_2}.  The
-#' number of occurrences before and after the polarized word are multiplied by
+#' The adversative conjunctions (i.e., 'but', 'however', and 'although') also 
+#' weight the context cluster.  A adversative conjunction before the polarized 
+#' word (\eqn{w_{adversative\,conjunction}, ..., w_{i, j, k}^{p}}) up-weights 
+#' the cluster by 
+#' \eqn{1 + z_2 * \{|w_{adversative\,conjunction}|, ..., w_{i, j, k}^{p}\}} 
+#' (.85 is the default weight (\eqn{z_2})).  An adversative conjunction after 
+#' the polarized word down-weights the cluster by
+#' \eqn{1 + \{w_{i, j, k}^{p}, ..., |w_{adversative\,conjunction}| * -1\} * z_2}.  
+#' The number of occurrences before and after the polarized word are multiplied by
 #' 1 and -1 respectively and then summed within context cluster.  It is this
 #' value that is multiplied by the weight and added to 1. This
-#' corresponds to the belief that a but makes the next clause of greater values
-#' while lowering the value placed on the prior clause.
+#' corresponds to the belief that an adversative conjunction makes the next 
+#' clause of greater values while lowering the value placed on the prior clause.
 #'
 #' The researcher may provide a weight \eqn{z} to be utilized with
 #' amplifiers/de-amplifiers (default is .8; de-amplifier weight is constrained
@@ -155,7 +179,7 @@
 #'
 #' \deqn{w_{b} = 1 + z_2 * w_{b'}}
 #'
-#' \deqn{w_{b'} = \sum{\\(|w_{but\,conjunction}|, ..., w_{i, j, k}^{p}, w_{i, j, k}^{p}, ..., |w_{but\,conjunction}| * -1}\\)}
+#' \deqn{w_{b'} = \sum{\\(|w_{adversative\,conjunction}|, ..., w_{i, j, k}^{p}, w_{i, j, k}^{p}, ..., |w_{adversative\,conjunction}| * -1}\\)}
 #'
 #' \deqn{w_{neg}= \left(\sum{w_{i,j,k}^{n}}\right) \bmod {2}}
 #'
@@ -173,13 +197,18 @@
 #' plot(sam)
 #' plot(sam, scale_range = TRUE, low_pass_size = 5)
 #' plot(sam, scale_range = TRUE, low_pass_size = 10)
+#'     
+#' plot(sam, transformation.function = syuzhet::get_transformed_values)
+#' plot(sam, transformation.function = syuzhet::get_transformed_values,  
+#'     scale_range = TRUE, low_pass_size = 5)
+#' 
 #' y <- "He was not the sort of man that one would describe as especially handsome."
 #' sentiment(y)
 #' sentiment(y, n.before=Inf)
-sentiment <- function(text.var, polarity_dt = sentimentr::polarity_table,
-    valence_shifters_dt = sentimentr::valence_shifters_table, hyphen = "",
+sentiment <- function(text.var, polarity_dt = lexicon::hash_sentiment_jockers,
+    valence_shifters_dt = lexicon::hash_valence_shifters, hyphen = "",
     amplifier.weight = .8, n.before = 5, n.after = 2, question.weight = 1,
-    but.weight = .85, missing_value = 0, ...){
+    adversative.weight = .85, missing_value = 0, ...){
 
     sentences <- id2 <- pol_loc <- comma_loc <- P <- non_pol <- lens <-
             cluster_tag <- w_neg <- neg <- A <- a <- D <- d <- wc <- id <-
@@ -187,7 +216,7 @@ sentiment <- function(text.var, polarity_dt = sentimentr::polarity_table,
 
     ## check to ake sure valence_shifters_dt polarity_dt are mutually exclusive
     if(any(valence_shifters_dt[[1]] %in% polarity_dt[[1]])) {
-        stop('`polarity_frame` & `valence_shifters_dt` not mutually exclusive')
+        stop('`polarity_dt` & `valence_shifters_dt` not mutually exclusive')
     }
 
     ## Add "~~" holder for any words `polarity_frame` & `valence_shifters_dt`
@@ -245,7 +274,7 @@ sentiment <- function(text.var, polarity_dt = sentimentr::polarity_table,
     but_dat <- word_dat[cluster_tag == "4", list(
     	b =  before*sum2(cluster_tag %in% "4")),
         by = c("id", "id2", "pol_loc", "before")][, before := NULL][,
-            list(b = 1 + but.weight*sum2(b)), by = c("id", "id2", "pol_loc")]
+            list(b = 1 + adversative.weight*sum2(b)), by = c("id", "id2", "pol_loc")]
 
     ## Get counts of negators (neg), amplifiers (a), and deamplifiers (d)
     ## neg is changed to a simple 0/1 if it flips the sign or not
@@ -263,7 +292,7 @@ sentiment <- function(text.var, polarity_dt = sentimentr::polarity_table,
     sent_dat <- merge(merge(pol_dat, sent_dat[,  c("id", "id2", "wc"), with=FALSE],
         by = c("id", "id2")),	word_dat, by = c("id", "id2", "pol_loc"))
 
-    ## add in the but weights
+    ## add in the adversative weights
     sent_dat[, a := a + ifelse(!is.na(b) & b > 1, b, 0)]
     sent_dat[, d := d + ifelse(!is.na(b) & b < 1, b, 0)]
 
@@ -307,15 +336,17 @@ replace_na <- function(x, y = 0) {x[is.na(x)] <- y; x}
 #' Plots a sentiment object.
 #'
 #' @param x The sentiment object.
+#' @param transformation.function A transformation function to smooth the sentiment
+#' scores.
 #' @param \ldots Other arguments passed to \code{\link[syuzhet]{get_transformed_values}}.
 #' @details Utilizes Matthew Jocker's \pkg{syuzhet} package to calculate smoothed
 #' sentiment across the duration of the text.
 #' @return Returns a \pkg{ggplot2} object.
 #' @method plot sentiment
 #' @export
-plot.sentiment <- function(x, ...){
+plot.sentiment <- function(x, transformation.function = syuzhet::get_dct_transform, ...){
 
-    m <- syuzhet::get_transformed_values(stats::na.omit(x[["sentiment"]]), ...)
+    m <- transformation.function(stats::na.omit(x[["sentiment"]]), ...)
 
     dat <- data.frame(
         Emotional_Valence = m,
